@@ -1,24 +1,24 @@
 mod error;
 mod prop_type;
-mod properties;
-mod property;
 mod schema;
 mod schematic;
 
-pub use error::RschemaError;
+pub use error::Error;
 pub use prop_type::{
     ArrayProp,
     EnumProp,
     Items,
     NumericProp,
     ObjectProp,
+    Properties,
+    Property,
     PropType,
     StringProp,
     TupleProp,
 };
-pub use properties::Properties;
-pub use property::Property;
 pub use schema::Schema;
 pub use schematic::Schematic;
 
-pub type Result<T> = std::result::Result<T, RschemaError>;
+/// Alias for a `Result` with the error type `rschema::Error`.
+/// 
+pub type Result<T> = std::result::Result<T, Error>;
